package httpheader

// AcceptLanguage returns the Accept-Language header used for measuring.
func AcceptLanguage() string {
	return "en-US,en;q=0.9"
}
